[asterisk-bugs] [Asterisk 0016526]: Support for SonyEricsson T6x0 and friends is broken

Asterisk Bug Tracker noreply at bugs.digium.com
Wed Dec 30 08:13:02 CST 2009


The following issue has been SUBMITTED. 
====================================================================== 
https://issues.asterisk.org/view.php?id=16526 
====================================================================== 
Reported By:                eugenesan
Assigned To:                mnicholson
====================================================================== 
Project:                    Asterisk
Issue ID:                   16526
Category:                   Addons/chan_mobile
Reproducibility:            always
Severity:                   major
Priority:                   normal
Status:                     assigned
Asterisk Version:           1.6.2.0 
JIRA:                        
Regression:                 No 
Reviewboard Link:            
SVN Branch (only for SVN checkouts, not tarball releases): N/A 
SVN Revision (number only!):  
Request Review:              
====================================================================== 
Date Submitted:             2009-12-30 08:13 CST
Last Modified:              2009-12-30 08:13 CST
====================================================================== 
Summary:                    Support for SonyEricsson T6x0 and friends is broken
Description: 
Module in it's current state (1.6.2.0+) fails to operate SonyEricsson T630
and probably simalar devices.

After solving initialization problem (patch attached) I've found that this
device call reporting behavior is differs much from embedded in module.

In past those devices were reported as working, so I assume their support
as broken.

Patch:
======
--- a/channels/chan_mobile.c	2009-12-28 19:52:53.000000000 +0200
+++ b/channels/chan_mobile.c	2009-12-30 12:29:31.306353568 +0200
@@ -3098,7 +3098,16 @@
 		}
 		msg_queue_free_and_pop(pvt);
 	} else if (entry) {
-		ast_debug(1, "[%s] received AT message 'ERROR' when expecting %s,
ignoring\n", pvt->id, at_msg2str(entry->expected));
+		if ( (entry->expected == AT_BRSF) && (!(pvt->hfp->initialized)) ) {
+			ast_debug(1, "[%s] received AT message 'ERROR' when expecting %s,
Trying CIND as fallback\n", pvt->id, at_msg2str(entry->expected));
+			msg_queue_free_and_pop(pvt);
+			if (hfp_send_cind(pvt->hfp)  || msg_queue_push(pvt, AT_CIND, AT_CIND))
{
+				ast_debug(1, "[%s] error sending CIND\n", pvt->hfp->owner->id);
+				goto e_return;
+			}
+		} else {
+			ast_debug(1, "[%s] received AT message 'ERROR' when expecting %s,
Ignoring\n", pvt->id, at_msg2str(entry->expected));
+		}
 	} else {
 		ast_debug(1, "[%s] received unexpected AT message 'ERROR'\n",
pvt->id);
 	}
@@ -3374,7 +3383,7 @@
 	 * procedure is not spread throughout the event handling loop.
 	 */
 
 	/* start initialization with the BRSF request */
 	ast_mutex_lock(&pvt->lock);
 	pvt->timeout = 10000;
 	if (hfp_send_brsf(hfp, &hfp_our_brsf)  || msg_queue_push(pvt, AT_BRSF,
@@ -3374,7 +3383,7 @@
 	 */
 
-	/* start initialization with the BRSF request */
+	/* start initialization with the BRSF request, with fallback to CIND*/
 	ast_mutex_lock(&pvt->lock);
 	pvt->timeout = 10000;
AT_BRSF)) {


====================================================================== 

Issue History 
Date Modified    Username       Field                    Change               
====================================================================== 
2009-12-30 08:13 eugenesan      New Issue                                    
2009-12-30 08:13 eugenesan      Status                   new => assigned     
2009-12-30 08:13 eugenesan      Assigned To               => mnicholson      
2009-12-30 08:13 eugenesan      Asterisk Version          => 1.6.2.0         
2009-12-30 08:13 eugenesan      Regression                => No              
2009-12-30 08:13 eugenesan      SVN Branch (only for SVN checkouts, not tarball
releases) => N/A             
======================================================================




More information about the asterisk-bugs mailing list